@@ -1,15 +1,15 @@
 package HeliosX::Job::JSON::TestService;
 
-use 5.010;
+use 5.008;
 use strict;
 use warnings;
-use parent 'Helios::Service';
+use base 'Helios::Service';
 
 use Helios::Config;
 use Helios::LogEntry::Levels qw(:all);
 use HeliosX::Job::JSON;
 
-our $VERSION = '0.01_3460';
+our $VERSION = '0.02_3670';
 
 sub JobClass { 'HeliosX::Job::JSON' }
 
@@ -21,7 +21,7 @@ sub run {
 	
 	eval {
 		$self->logMsg($job, LOG_INFO, __PACKAGE__." says 'Hello World!'");
-		foreach (keys %$args) {
+		foreach ( keys %{$args} ) {
 			$self->logMsg($job, LOG_INFO, 'ARG: '.$_.' VALUE: '.$args->{$_});
 		}
 		
